# del-msh

Python 🐍 static 2D/3D mesh utility library for computer graphics 📺 research 🧑‍🔬 and prototyping 🪚.

Look [python demos](https://github.com/nobuyuki83/python_graphics_demos) for the coding examples 

> [!WARNING]
> **del-msh** is still in its initial development phase. Crates published to https://pypi.org/project/del-msh/ in the 0.1.x series do not obey SemVer and are unstable.

## Install 

```shell
pip install del-msh
```

